==> kubernetes-model-core-4.13.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/PreconditionsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PreconditionsBuilder extends PreconditionsFluentImpl<PreconditionsBuilder> implements VisitableBuilder<Preconditions,PreconditionsBuilder> {

    PreconditionsFluent<?> fluent;
    Boolean validationEnabled;

    public PreconditionsBuilder() { 
        this(true);
    }


    public PreconditionsBuilder(Boolean validationEnabled) { 
        this(new Preconditions(), validationEnabled);
    }


    public PreconditionsBuilder(PreconditionsFluent<?> fluent) { 
        this(fluent, true);
    }


    public PreconditionsBuilder(PreconditionsFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new Preconditions(), validationEnabled);
    }


    public PreconditionsBuilder(PreconditionsFluent<?> fluent,Preconditions instance) { 
        this(fluent, instance, true);
    }


    public PreconditionsBuilder(PreconditionsFluent<?> fluent,Preconditions instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withResourceVersion(instance.getResourceVersion()); 
        fluent.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }


    public PreconditionsBuilder(Preconditions instance) { 
        this(instance,true);
    }


    public PreconditionsBuilder(Preconditions instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withResourceVersion(instance.getResourceVersion()); 
        this.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }


    public Preconditions build() {
        Preconditions buildable = new Preconditions(fluent.getResourceVersion(),fluent.getUid());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PreconditionsBuilder that = (PreconditionsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/PreconditionsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PreconditionsBuilder extends PreconditionsFluentImpl<PreconditionsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<Preconditions,PreconditionsBuilder> {

    PreconditionsFluent<?> fluent;
    Boolean validationEnabled;

    public PreconditionsBuilder() {
        this(true);
    }

    public PreconditionsBuilder(Boolean validationEnabled) {
        this(new Preconditions(), validationEnabled);
    }

    public PreconditionsBuilder(PreconditionsFluent<?> fluent) {
        this(fluent, true);
    }

    public PreconditionsBuilder(PreconditionsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Preconditions(), validationEnabled);
    }

    public PreconditionsBuilder(PreconditionsFluent<?> fluent,Preconditions instance) {
        this(fluent, instance, true);
    }

    public PreconditionsBuilder(PreconditionsFluent<?> fluent,Preconditions instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withResourceVersion(instance.getResourceVersion()); 
        fluent.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public PreconditionsBuilder(Preconditions instance) {
        this(instance,true);
    }

    public PreconditionsBuilder(Preconditions instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withResourceVersion(instance.getResourceVersion()); 
        this.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public Preconditions build() {
        Preconditions buildable = new Preconditions(fluent.getResourceVersion(),fluent.getUid());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PreconditionsBuilder that = (PreconditionsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
